Module probability

Module probability 

Structs

Probability
A validated probability value in the closed interval [0, 1].

Functions

independent_intersection
Returns the probability of two independent events both happening.
independent_union
Returns the probability of at least one of two independent events happening.